@@ -100,14 +100,14 @@ class StableDiffusionControlNetCannyGenerator:
 
                     controlnet_canny_prompt = gr.Textbox(
                         lines=1,
-                        label="Prompt",
                         placeholder="Prompt",
+                        show_label=False,
                     )
 
                     controlnet_canny_negative_prompt = gr.Textbox(
                         lines=1,
-                        label="Negative Prompt",
                         placeholder="Negative Prompt",
+                        show_label=False,
                     )
                     with gr.Row():
                         with gr.Column():
